@@ -1,50 +1,10 @@
 leaflet_classes_ronds <-
-function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,varRatio,rayonRond=NULL,rapportRond=NULL,methode="kmeans",nbClasses=3,bornes=NULL,precision=1,dom="0",fondChx=NULL)
+function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,varRatio,rayonRond=NULL,rapportRond=NULL,methode="kmeans",nbClasses=3,bornes=NULL,stylePalette="defaut",opacityElargi=0.6,colBorderClasses="white",colBorderRonds="#303030",precision=1,dom="0",fondChx=NULL,map_proxy=NULL)
   {
     options("stringsAsFactors"=FALSE)
     
     # Verification des parametres
-    
-    msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17<-msg_error18<-msg_error19<-msg_error20<-msg_error21<-msg_error22<-msg_error23<-msg_error24 <- NULL
-    
-    if(any(class(data)!="data.frame")) msg_error1 <- "Les donnees doivent etre dans un data.frame / "
-    if(any(!any(class(fondMaille) %in% "sf"),!any(class(fondMaille) %in% "data.frame"))) msg_error2 <- "Le fond de maille doit etre un objet sf / "
-    if(!is.null(fondMailleElargi)) if(any(!any(class(fondMailleElargi) %in% "sf"),!any(class(fondMailleElargi) %in% "data.frame"))) msg_error3 <- "Le fond de maille elargie doit etre un objet sf / "
-    if(!is.null(fondSuppl)) if(any(!any(class(fondSuppl) %in% "sf"),!any(class(fondSuppl) %in% "data.frame"))) msg_error4 <- "Le fond supplementaire doit etre un objet sf / "
-    if(any(class(idData)!="character")) msg_error5 <- "Le nom de la variable doit etre de type caractere / "
-    if(any(class(varVolume)!="character")) msg_error6 <- "Le nom de la variable doit etre de type caractere / "
-    if(!is.null(rayonRond)) if(any(class(rayonRond)!="numeric")) msg_error7 <- "La variable doit etre de type numerique / "
-    if(!is.null(rapportRond)) if(any(class(rapportRond)!="numeric")) msg_error8 <- "La variable doit etre de type numerique / "
-    if(any(class(varRatio)!="character")) msg_error9 <- "Le nom de la variable doit etre de type caractere / "
-    if(any(class(methode)!="character")) msg_error10 <- "La nom de la methode doit etre de type caractere / "
-    if(any(class(nbClasses)!="numeric")) msg_error11 <- "La variable doit etre de type numerique / "
-    if(!is.null(bornes)) if(any(class(bornes)!="numeric")) msg_error12 <- "La variable doit etre un vecteur numerique / "
-    if(any(class(dom)!="character")) msg_error13 <- "La valeur doit etre de type caractere ('0', '971', '972', '973', '974' ou '976') / "
-    if(any(class(precision)!="numeric")) msg_error14 <- "La variable doit etre de type numerique / "
-    if(!is.null(fondChx)) if(any(!any(class(fondChx) %in% "sf"),!any(class(fondChx) %in% "data.frame"))) msg_error15 <- "Le fond des chx doit etre un objet sf / "
-    
-    if(length(names(data))<2) msg_error16 <- "Le tableau des donnees n'est pas conforme. Il doit contenir au minimum une variable identifiant et la variable a representer / "
-    if(length(names(fondMaille))<3) msg_error17 <- "Le fond de maille n'est pas conforme. La table doit contenir au minimum une variable identifiant, une variable libelle et la geometry / "
-    if(!is.null(fondMailleElargi)) if(length(names(fondMailleElargi))<3) msg_error18 <- "Le fond de maille elargie n'est pas conforme. La table doit contenir au minimum une variable identifiant, une variable libelle et la geometry / "
-    if(!is.null(fondSuppl)) if(length(names(fondSuppl))<3) msg_error19 <- "Le fond supplementaire n'est pas conforme. La table doit contenir au minimum une variable identifiant, une variable libelle et la geometry / "
-    
-    if(!any(names(data) %in% idData))  msg_error20 <- "La variable identifiant les donnees n'existe pas dans la table des donnees / "
-    if(!any(names(data) %in% varVolume))  msg_error21 <- "La variable a representer n'existe pas dans la table des donnees / "
-    if(!any(names(data) %in% varRatio))  msg_error22 <- "La variable a representer n'existe pas dans la table des donnees / "
-    if(!methode %in% c("kmeans","fisher","jenks","quantile")) msg_error23 <- "Le nom de la methode doit etre 'kmeans', 'fisher', 'jenks' ou 'quantile' / "
-    if(!dom %in% c("0","971","972","973","974","976")) msg_error24 <- "La variable dom doit etre '0', '971', '972', '973', '974' ou '976' / "
-    
-    if(any(!is.null(msg_error1),!is.null(msg_error2),!is.null(msg_error3),!is.null(msg_error4),
-           !is.null(msg_error5),!is.null(msg_error6),!is.null(msg_error7),!is.null(msg_error8),
-           !is.null(msg_error9),!is.null(msg_error10),!is.null(msg_error11),!is.null(msg_error12),
-           !is.null(msg_error13),!is.null(msg_error14),!is.null(msg_error15),!is.null(msg_error16),
-           !is.null(msg_error17),!is.null(msg_error18),!is.null(msg_error19),!is.null(msg_error20),
-           !is.null(msg_error21),!is.null(msg_error22),!is.null(msg_error23),!is.null(msg_error24)))
-    {
-      stop(simpleError(paste0(msg_error1,msg_error2,msg_error3,msg_error4,msg_error5,msg_error6,msg_error7,msg_error8,
-                              msg_error9,msg_error10,msg_error11,msg_error12,msg_error13,msg_error14,msg_error15,msg_error16,
-                              msg_error17,msg_error18,msg_error19,msg_error20,msg_error21,msg_error22,msg_error23,msg_error24)))
-    }
+    leafletVerifParamClassesRonds(data,fondMaille,fondMailleElargi,fondSuppl,idData,varVolume,varRatio,rayonRond,rapportRond,methode,nbClasses,bornes,stylePalette,opacityElargi,colBorderClasses,colBorderRonds,precision,dom,fondChx,map_proxy)
     
     if(!is.null(fondChx))
     {
@@ -76,6 +36,17 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     
     fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","utf8")
     
+    if(!is.null(map_proxy))
+    {
+      if(any(class(map_proxy) %in% "leaflet_proxy")) # Contexte shiny/proxy
+      {
+        clearGroup(map_proxy, group = "carte_classes")
+        clearGroup(map_proxy, group = "carte_ronds")
+        clearGroup(map_proxy, group = "carte_ronds_elargi")
+        clearGroup(map_proxy, group = "carte_classes_elargi")
+      }
+    }
+    
     if(is.null(fondMailleElargi))
     {
       elargi <- FALSE
@@ -112,9 +83,21 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     
     if(!is.null(rayonRond))
     {
-      if(rayonRond>max_rayon_metres)
+      if(!is.na(rayonRond))
       {
-        stop(simpleError(paste0("Le rayon du rond le plus grand est trop eleve et ne permet pas de respecter la regle semiologique des 1/7eme. Le rayon max est ",round(max_rayon_metres,2)," metres.")))
+        if(rayonRond>max_rayon_metres)
+        {
+          if(!is.null(map_proxy))
+          {
+            showModal(modalDialog(HTML(paste0("Le rayon du rond le plus grand est trop \u00e9lev\u00e9 et ne permet pas de respecter la r\u00e8gle s\u00e9miologique des 1/7\u00e8me. Le rayon max est ",round(max_rayon_metres,2)," m\u00e8tres.")), size="l", footer=NULL, easyClose = TRUE, style = "color: #fff; background-color: #DF691A; border-color: #2e6da4")) #337ab7
+          }else
+          {
+            stop(simpleError(paste0("Le rayon du rond le plus grand est trop eleve et ne permet pas de respecter la regle semiologique des 1/7eme. Le rayon max est ",round(max_rayon_metres,2)," metres.")))
+          }
+        }
+      }else
+      {
+        rayonRond <- max_rayon_metres
       }
     }
     
@@ -134,7 +117,14 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     
     if(is.null(analyse))
     {
-      stop(simpleError("La maille ne correspond pas au niveau geographique du fichier de donnees. Veuillez svp choisir une maille adaptee ou modifier le fichier de donnees."))
+      if(!is.null(map_proxy))
+      {
+        showModal(modalDialog(HTML(paste0("<font size=+1>La maille ne correspond pas au niveau g\u00e9ographique du fichier de donn","\u00e9","es.<br><br>Veuillez svp choisir une maille adapt","\u00e9","e ou modifier le fichier de donn","\u00e9","es.</font>")), size="l", footer=NULL, easyClose = TRUE, style = "color: #fff; background-color: #DF691A; border-color: #2e6da4")) #337ab7
+        return(map_proxy)
+      }else
+      {
+        stop(simpleError("La maille ne correspond pas au niveau geographique du fichier de donnees. Veuillez svp choisir une maille adaptee ou modifier le fichier de donnees"))
+      }
     }
     
     analyse$donnees[,varRatio] <- round(analyse$donnees[,varRatio],precision)
@@ -159,27 +149,57 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     
     if(is.null(bornes))
     {
-      suppressWarnings(bornes_analyse <- classIntervals(as.numeric(analyse$donnees[,varRatio]),nbClasses,style=methode,rtimes=10,intervalClosure="left"))
+      suppressWarnings(test_bornes_analyse <- try(classIntervals(as.numeric(analyse$donnees[,varRatio]),nbClasses,style=methode,rtimes=10,intervalClosure="left"),silent=TRUE))
       
-      carac_bornes <- calcul_bornes(analyse$donnees,bornes_analyse,varRatio,nbClasses,methode)
+      if(!class(test_bornes_analyse) %in% "try-error")
+      {
+        suppressWarnings(bornes_analyse <- classIntervals(as.numeric(analyse$donnees[,varRatio]),nbClasses,style=methode,rtimes=10,intervalClosure="left"))
+      }else
+      {
+        if(!is.null(map_proxy))
+        {
+          showModal(modalDialog(HTML("<font size=+1>Le nombre de classes n'est pas adapt\u00e9 \u00e0 l'analyse.</font>"), size="l", footer=NULL, easyClose = TRUE, style = "color: #fff; background-color: #DF691A; border-color: #2e6da4")) #337ab7
+          return(map_proxy)
+        }else
+        {
+          stop(simpleError("Le nombre de classes n'est pas adapte a l'analyse."))
+        }
+      }
+      
+      suppressWarnings(test_calcul_bornes <- try(calcul_bornes(analyse$donnees,bornes_analyse,varRatio,nbClasses,methode,stylePalette),silent=TRUE))
+      
+      if(!class(test_calcul_bornes) %in% "try-error")
+      {
+        carac_bornes <- calcul_bornes(analyse$donnees,bornes_analyse,varRatio,nbClasses,methode,stylePalette)
+      }else
+      {
+        if(!is.null(map_proxy))
+        {
+          showModal(modalDialog(HTML(paste0("<font size=+1>La maille ne correspond pas au niveau g\u00e9ographique du fichier de donn","\u00e9","es.<br><br>Veuillez svp choisir une maille adapt","\u00e9","e ou modifier le fichier de donn","\u00e9","es.</font>")), size="l", footer=NULL, easyClose = TRUE, style = "color: #fff; background-color: #DF691A; border-color: #2e6da4")) #337ab7
+          return(map_proxy)
+        }else
+        {
+          stop(simpleError("La maille ne correspond pas au niveau geographique du fichier de donnees. Veuillez svp choisir une maille adaptee ou modifier le fichier de donnees"))
+        }
+      }
       
       bornes <- carac_bornes[[1]]
       bornes[1] <- max(as.numeric(analyse$donnees[,varRatio]))
       bornes_sansext <- bornes[-1]
       bornes_sansext <- bornes_sansext[-length(bornes_sansext)]
-      bornes_sansext <- sort(bornes, decreasing = TRUE)
+      bornes_sansext <- sort(bornes_sansext, decreasing = TRUE)
       bornes <- unique(c(max,bornes_sansext,min))
       bornes <- round(bornes,precision)
-      
       pal_classes <- carac_bornes[[2]]
+      
     }else
     {
       bornes_sansext <- sort(bornes, decreasing = TRUE)
       bornes <- unique(c(max,bornes_sansext,min))
       bornes <- round(bornes,precision)
       
-      pal_classes_pos <- c("#5A0A14","#82141B","#9B231C","#B24B1D","#D47130","#E4A75A","#F2CE93") # Rouge du +fonce au + clair
-      pal_classes_neg <- c("#C9DAF0","#95BAE2","#5182B6","#005289","#003269","#001E5A","#000050") # Bleu du + clair au + fonce
+      pal_classes_pos <- recup_palette(stylePalette)[[1]]
+      pal_classes_neg <- recup_palette(stylePalette)[[2]]
       
       if(min<0 & max>=0) # Si - et +
       {
@@ -210,6 +230,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     }
     
     pal_classes[is.na(pal_classes)] <- "grey"
+    
     palette<-colorBin(palette=rev(pal_classes), domain=0:100, bins=bornes, na.color="grey")
     
     # Fonds habillages
@@ -266,84 +287,102 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     
     # Construction de la map par defaut
     
-    map <- leaflet(padding = 0,
-                   options = leafletOptions(
-                     preferCanvas = TRUE,
-                     transition = 2,
-                     minZoom = 6,
-                     maxZoom = 10
-                   )) %>%
-      
-      setMapWidgetStyle(list(background = "#AFC9E0")) %>%
-      
-      addTiles_insee(attribution = paste0("<a href=\"http://www.insee.fr\">\u00A9 IGN - INSEE ",format(Sys.time(), format = "%Y"),"</a>")) %>%
-      
-      fitBounds(lng1 = min(list_bbox[[1]]),
-                lat1 = min(list_bbox[[2]]),
-                lng2 = max(list_bbox[[1]]),
-                lat2 = max(list_bbox[[2]])
-      ) %>%
-      
-      # On ajoute une barre d'echelle
-      addScaleBar(position = 'bottomright',
-                  options = scaleBarOptions(metric = TRUE, imperial = FALSE)
-      )
-    
-    # AFFICHAGE DES FONDS D'HABILLAGE
-    if(dom %in% c("0","973"))
+    if(is.null(map_proxy) | (!is.null(map_proxy) & class(map_proxy)=="character"))
     {
-      map <- addPolygons(map = map, data = fond_pays[,"LIBGEO"], opacity = 1, # fond_pays sauf la France
-                         stroke = TRUE, color = "white",
-                         weight = 1,
-                         popup = as.data.frame(fond_pays[,"LIBGEO"])[,-ncol(as.data.frame(fond_pays[,"LIBGEO"]))],
-                         options = pathOptions(clickable = F),
-                         fill = T, fillColor = "#CCCCCC", fillOpacity = 1,
-                         group = list(nom_couche="carte_classes_ronds",code_epsg=code_epsg,nom_fond="fond_pays")
-                         
+      map <- leaflet(padding = 0,
+                     options = leafletOptions(
+                       preferCanvas = TRUE,
+                       transition = 2
+                     )) %>%
+        
+        setMapWidgetStyle(list(background = "#AFC9E0")) %>%
+        
+        addTiles_insee(attribution = paste0("<a href=\"http://www.insee.fr\">OCEANIS - \u00A9 IGN - INSEE ",format(Sys.time(), format = "%Y"),"</a>")) %>%
+        
+        fitBounds(lng1 = min(list_bbox[[1]]),
+                  lat1 = min(list_bbox[[2]]),
+                  lng2 = max(list_bbox[[1]]),
+                  lat2 = max(list_bbox[[2]])
+        ) %>%
+        
+        # Pour gerer l'ordre des calques
+        addMapPane(name = "fond_pays", zIndex = 401) %>%
+        addMapPane(name = "fond_france", zIndex = 402) %>%
+        addMapPane(name = "fond_territoire", zIndex = 403) %>%
+        addMapPane(name = "fond_classes_elargi", zIndex = 404) %>%
+        addMapPane(name = "fond_classes", zIndex = 405) %>%
+        addMapPane(name = "fond_ronds_elargi", zIndex = 406) %>%
+        addMapPane(name = "fond_ronds", zIndex = 407) %>%
+        addMapPane(name = "fond_legende", zIndex = 408) %>%
+      
+        # On ajoute une barre d'echelle
+        addScaleBar(position = 'bottomright',
+                    options = scaleBarOptions(metric = TRUE, imperial = FALSE)
+        )
+      
+      # AFFICHAGE DES FONDS D'HABILLAGE
+      if(dom %in% c("0","973"))
+      {
+        map <- addPolygons(map = map, data = fond_pays[,"LIBGEO"], opacity = 1, # fond_pays sauf la France
+                           stroke = TRUE, color = colBorderClasses,
+                           weight = 1,
+                           popup = as.data.frame(fond_pays[,"LIBGEO"])[,-ncol(as.data.frame(fond_pays[,"LIBGEO"]))],
+                           options = pathOptions(pane = "fond_pays", clickable = F),
+                           fill = T, fillColor = "#CCCCCC", fillOpacity = 1,
+                           group = "carte_classes_ronds_init",
+                           layerId = list(code_epsg=code_epsg,nom_fond="fond_pays")
+                           
+        )
+      }
+      
+      map <- addPolygons(map = map, data = fond_france[,"LIBGEO"], opacity = 1, # fond_france
+                         stroke = TRUE, color = "black",
+                         weight = 1.5,
+                         popup = as.data.frame(fond_france[,"LIBGEO"])[,-ncol(as.data.frame(fond_france[,"LIBGEO"]))],
+                         options = pathOptions(pane = "fond_france", clickable = F),
+                         fill = T, fillColor = "white", fillOpacity = 1,
+                         group = "carte_classes_ronds_init",
+                         layerId = list(code_epsg=code_epsg,nom_fond="fond_france")
       )
-    }
-    
-    map <- addPolygons(map = map, data = fond_france[,"LIBGEO"], opacity = 1, # fond_france
-                       stroke = TRUE, color = "black",
-                       weight = 1.5,
-                       popup = as.data.frame(fond_france[,"LIBGEO"])[,-ncol(as.data.frame(fond_france[,"LIBGEO"]))],
-                       options = pathOptions(clickable = F),
-                       fill = T, fillColor = "white", fillOpacity = 1,
-                       group = list(nom_couche="carte_classes_ronds",code_epsg=code_epsg,nom_fond="fond_france")
-    )
-    
-    # AFFICHAGE DU FOND TERRITOIRE
-    
-    if(!is.null(fondSuppl))
+      
+      # AFFICHAGE DU FOND TERRITOIRE
+      
+      if(!is.null(fondSuppl))
+      {
+        map <- addPolygons(map = map, data = fond_territoire,
+                           stroke = TRUE, color = "#BFBFBF", opacity = 1,
+                           weight = 0.5,
+                           options = pathOptions(pane = "fond_territoire", clickable = T),
+                           popup = paste0("<b> <font color=#2B3E50>",as.data.frame(fond_territoire)[,"LIBELLE"], "</font> </b>"),
+                           fill = T, fillColor = "white", fillOpacity = 0.001,
+                           group = "carte_classes_ronds_init",
+                           layerId = list(code_epsg=code_epsg,nom_fond="fond_territoire")
+        )
+      }
+    }else # Contexte shiny/proxy
     {
-      map <- addPolygons(map = map, data = fond_territoire,
-                         stroke = TRUE, color = "#BFBFBF", opacity = 1,
-                         weight = 0.5,
-                         options = pathOptions(clickable = T),
-                         popup = paste0("<b> <font color=#2B3E50>",as.data.frame(fond_territoire)[,"LIBELLE"], "</font> </b>"),
-                         fill = T, fillColor = "white", fillOpacity = 0.001,
-                         group = list(nom_couche="carte_classes_ronds",code_epsg=code_epsg,nom_fond="fond_territoire")
-      )
+      map <- map_proxy
     }
     
     if(!is.null(fondMailleElargi))
     {
       # AFFICHAGE DE LA MAILLE ET DE L'ANALYSE EN CLASSES ELARGIE
       
-      analyse_maille_classe <- analyse$donnees_elargi[rev(order(analyse$donnees_elargi[,varRatio])),varRatio]
+      analyse_maille_classe_elargi <- analyse$donnees_elargi[rev(order(analyse$donnees_elargi[,varRatio])),varRatio]
       
       analyse_maille_elargi <- merge(maille_WGS84_elargi[,c("CODE","geometry")],analyse$donnees_elargi,by="CODE")
       analyse_maille_elargi <- analyse_maille_elargi[rev(order(as.data.frame(analyse_maille_elargi)[,varRatio])),c("CODE","LIBELLE",varRatio,"TXT1","TXT2","geometry")]
       analyse_maille_elargi <- st_sf(analyse_maille_elargi,stringsAsFactors = FALSE)
       
-      map <- addPolygons(map = map, data = analyse_maille_elargi, opacity = 0.6,
-                         stroke = TRUE, color = "white", weight = 1,
-                         options = pathOptions(clickable = T),
+      map <- addPolygons(map = map, data = analyse_maille_elargi, opacity = opacityElargi,
+                         stroke = TRUE, color = colBorderClasses, weight = 1,
+                         options = pathOptions(pane = "fond_classes_elargi", clickable = T),
                          popup = paste0("<b> <font color=#2B3E50>",as.data.frame(analyse_maille_elargi)$LIBELLE, "</font> </b><br><b> <font color=#2B3E50>",varVolume," : </font></b>",as.data.frame(analyse_maille_elargi)$TXT1,"<br><b><font color=#2B3E50>",varRatio," : </font></b>",as.data.frame(analyse_maille_elargi)$TXT2),
                          fill = T,
-                         fillColor = palette(analyse_maille_classe),
-                         fillOpacity = 0.6,
-                         group = list(nom_couche="carte_classes_ronds",code_epsg=code_epsg,dom=dom,nom_fond="fond_maille_elargi_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style="defaut")
+                         fillColor = palette(analyse_maille_classe_elargi),
+                         fillOpacity = opacityElargi,
+                         group = "carte_classes_elargi",
+                         layerId = list(analyse_maille_elargi=analyse_maille_elargi,analyse_maille_classe_elargi=analyse_maille_classe_elargi,code_epsg=code_epsg,dom=dom,nom_fond="fond_maille_elargi_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorderClasses)
       )
     }
     
@@ -356,13 +395,14 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     analyse_maille <- st_sf(analyse_maille,stringsAsFactors = FALSE)
     
     map <- addPolygons(map = map, data = analyse_maille, opacity = 1,
-                       stroke = TRUE, color = "white", weight = 1,
-                       options = pathOptions(clickable = T),
+                       stroke = TRUE, color = colBorderClasses, weight = 1,
+                       options = pathOptions(pane = "fond_classes", clickable = T),
                        popup = paste0("<b> <font color=#2B3E50>",as.data.frame(analyse_maille)$LIBELLE, "</font> </b><br><b> <font color=#2B3E50>",varVolume," : </font></b>",as.data.frame(analyse_maille)$TXT1,"<br><b><font color=#2B3E50>",varRatio," : </font></b>",as.data.frame(analyse_maille)$TXT2),
                        fill = T,
                        fillColor = palette(analyse_maille_classe),
                        fillOpacity = 1,
-                       group = list(nom_couche="carte_classes_ronds",code_epsg=code_epsg,dom=dom,nom_fond="fond_maille_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style="defaut")
+                       group = "carte_classes",
+                       layerId = list(analyse_maille=analyse_maille,analyse_maille_classe=analyse_maille_classe,code_epsg=code_epsg,dom=dom,nom_fond="fond_maille_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorderClasses)
     )
     
     if(!is.null(fondMailleElargi))
@@ -372,14 +412,15 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
       map <- addCircles(map = map,
                         lng = st_coordinates(analyse_WGS84_elargi)[,1],
                         lat = st_coordinates(analyse_WGS84_elargi)[,2],
-                        stroke = TRUE, color = "#303030",
-                        opacity = 0.6,
+                        stroke = TRUE, color = colBorderRonds,
+                        opacity = opacityElargi,
                         weight = 1.5,
                         radius = rayonRond*sqrt(analyse$donnees_elargi[,varVolume]/max_var),
-                        options = pathOptions(clickable = F),
+                        options = pathOptions(pane = "fond_ronds_elargi", clickable = F),
                         popup = paste0("<b> <font color=#2B3E50>",as.data.frame(analyse_maille_elargi)$LIBELLE, "</font> </b><br><b> <font color=#2B3E50>",varVolume," : </font></b>",as.data.frame(analyse_maille_elargi)$TXT1),
                         fill = F,
-                        group = list(nom_couche="carte_classes_ronds",code_epsg=code_epsg,dom=dom,nom_fond="fond_ronds_elargi_carte",max_var=max_var,var_volume=varVolume)
+                        group = "carte_ronds_elargi",
+                        layerId = list(analyse_WGS84_elargi=analyse_WGS84_elargi,analyse=analyse,analyse_maille_elargi=analyse_maille_elargi,code_epsg=code_epsg,dom=dom,nom_fond="fond_classes_ronds_elargi_carte",max_var=max_var,var_volume=varVolume,rayonRond=rayonRond,col_border_ronds=colBorderRonds)
       )
     }
     
@@ -388,14 +429,15 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     map <- addCircles(map = map,
                       lng = st_coordinates(analyse_WGS84)[,1],
                       lat = st_coordinates(analyse_WGS84)[,2],
-                      stroke = TRUE, color = "#303030",
+                      stroke = TRUE, color = colBorderRonds,
                       opacity = 1,
                       weight = 1.5,
                       radius = rayonRond*sqrt(analyse$donnees[,varVolume]/max_var),
-                      options = pathOptions(clickable = F),
+                      options = pathOptions(pane = "fond_ronds", clickable = F),
                       popup = paste0("<b> <font color=#2B3E50>",as.data.frame(analyse_maille)$LIBELLE, "</font> </b><br><b> <font color=#2B3E50>",varVolume," : </font></b>",as.data.frame(analyse_maille)$TXT1),
                       fill = F,
-                      group = list(nom_couche="carte_classes_ronds",code_epsg=code_epsg,dom=dom,nom_fond="fond_ronds_carte",max_var=max_var,var_volume=varVolume)
+                      group = "carte_ronds",
+                      layerId = list(analyse_WGS84=analyse_WGS84,analyse=analyse,analyse_maille=analyse_maille,code_epsg=code_epsg,dom=dom,nom_fond="fond_classes_ronds_carte",max_var=max_var,var_volume=varVolume,rayonRond=rayonRond,col_border_ronds=colBorderRonds)
     )
     
     return(map)
